/******************************************************************************
 *            echecs_var.h                                                    *
 *                                                                            *
 *  Copyright  2006  gerald.dumas                                             *
 *  linechec@laposte.net                                                      *
 ******************************************************************************
 *                                                                            *
 *  This program is free software; you can redistribute it and/or modify      *
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  any later version.                                                        *
 *                                                                            *
 *  This program is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with this program; if not, write to the Free Software               *
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*
 ******************************************************************************/

/* déclarations liminaires des différentes variables globales*/
#include <string.h>
#include <gtk-2.0/gtk/gtk.h>

/* déclaration des variables et macros du jeu */

#if !defined(ECHECS_VAR)
#define ECHECS_VAR

#define DEBUG // si non définie, pas d'affichage d'info dans le cadre stat.

#define pion			1
#define cavalier	2
#define tour			3
#define fou				4
#define dame			5
#define roi				6

#define noire			1
#define noir			1
#define blanche		0
#define blanc			0
#define vide			0
#define bord			-1

#define CROISSANT	0
#define NBRE_COUPS_ADVERSE 2

extern gint8 rosace[7][9];	// Tableau contenant les != déplacements pour chaque type de pièce

// tableau de correspondance entre les pièces et leur rosace.
extern gint8 corres_piece[7];

struct struct_coup
{
  gchar *nom;
  gchar *coup;
};

struct struct_piece
{
  gchar type;			// pion, tour, cavalier ...
  gint couleur;			// noire ou blanche (quoi d'autre ? :-) )
  gint ponderation;		// Valeur de la pièce de manière échiquéenne
  gint place;			// position dans le tableau echiquier
  gchar nbre_cases_jouables;
  gchar deplacement_initial;	// utile pour les pions et les roques gboolean
};

// La structure struct_coups_jouables est utilisée pour la liste chaînées des
// coups jouables.
struct struct_coups_jouables
{
  gint pos_piece_tab;		// Position de la pièce dans le tableau table_piece.
  gint couleur;			// Couleur de la pièce
  gint8 coup;		// Coup jouable;
  gint8 valeur_coup;	// Estimation du coup
  gint8 nbre_coups_adverse;	// Utile pour le moteur de recherche de mat en x coups.
  gboolean case_occupee;	// Si ce coup "jouable" est en fait une case occupée,
  // Le flag coup_ami prend tout son sens.
  gboolean coup_ami;		// Un coup supplémentaire non jouable si vaut TRUE.
};

extern GList *liste_coups_jouables;

typedef struct struct_piece type_piece;	/* Définition générale d'une pièce.*/

struct struct_echiquier
{
  gint ponderation;		// Valeur échiquéenne de la case
  gint8 type_piece;		// Donne la position d'une pièce sur l'échiquier
  // (=0 (vide) si pas de pièce).
  gint8 couleur_piece;	// Couleur de la pièce dans cette case.
  gint8 couleur_case;	// Couleur de la case.
  gint pos_table_piece;		// Position de la pièce dans table_piece
  gint8 x;			// correspondance abscisse de l'échiquier
  gint8 y;			// correspondance ordonnée de l'échiquier
};

extern struct struct_echiquier echiquier[144];

extern type_piece table_piece[33];	// Tableau comportant toutes les pièces en jeu
																		// avec tous leurs coups jouables et différentes
																		// variables d'état.

struct struct_position_echiquier	// structure qui enregistre l'état d'une position du jeu
{
  type_piece table_piece[33];	// Sauvegarde de la table contenant toues les pièces
  struct struct_echiquier echiquier[144];	// Sauvegarde de l'écchiquier
  gchar *coup;			// Coup au format texte joué ( utile pour sauvegarder
  // la partie et pour comparer avec la bibliothèque ).
};

extern gboolean partie_en_cours;	// Indique si une partie est en cours de jeu.
extern gboolean partie_enregistree;	// Si une partie est en cours, indique si elle est sauvée
																		// à la position actuelle.

extern struct struct_position_echiquier tab_sauve_partie[200];	// tableau de sauvegarde de la partie en cours
extern gint num_coup_joue;	// n° du coup joué ( les n° impairs sont les coups blancs )
extern gint humain_joue;		// bascule pour la couleur jouable sur l'échiquier
extern gint couleur_humain;	// Couleur joué par l'humain.
extern gboolean gnuchess;	// Indique si c'est Gnuchess qui joue contre l'humain
extern gchar prise_en_passant;	// Vrai si une prise en passant est possible.

extern GKeyFile *key_file_config;	// Structure contenant toutes les variables de configuration

// Variables initialisées avec les options de commande.
extern gchar *connex;		// IP du serveur FICS
extern gchar *filename;	// Nom du fichier à charger au démarrage
extern gchar *username;	// Nom de l'utilisateur
extern gboolean debug;	// Affiche des indications sur les cases pointées


extern GOptionEntry entries[];	// Options de la ligne de commande

#endif
